import { TranslationCall, DocumentTranslation, Appointment, ApiResponse } from '../types';

// API基础URL
const API_BASE_URL = process.env.REACT_APP_API_URL || 'http://localhost:3001/api';

// API请求工具类
class ApiManager {
  private baseURL: string;

  constructor(baseURL: string = API_BASE_URL) {
    this.baseURL = baseURL;
  }

  // 通用请求方法
  private async request<T>(
    endpoint: string,
    options: RequestInit = {}
  ): Promise<ApiResponse<T>> {
    const url = `${this.baseURL}${endpoint}`;
    const config: RequestInit = {
      headers: {
        'Content-Type': 'application/json',
        ...options.headers,
      },
      ...options,
    };

    try {
      const response = await fetch(url, config);
      const data = await response.json();

      if (!response.ok) {
        throw new Error(data.message || '请求失败');
      }

      return {
        success: true,
        data,
        message: '操作成功',
      };
    } catch (error) {
      console.error('API请求错误:', error);
      return {
        success: false,
        data: null as any,
        message: error instanceof Error ? error.message : '网络错误',
      };
    }
  }

  // 通话管理API
  async getCall(id: string): Promise<ApiResponse<TranslationCall>> {
    return this.request<TranslationCall>(`/calls/${id}`);
  }

  async updateCall(id: string, data: Partial<TranslationCall>): Promise<ApiResponse<TranslationCall>> {
    return this.request<TranslationCall>(`/calls/${id}`, {
      method: 'PUT',
      body: JSON.stringify(data),
    });
  }

  async deleteCall(id: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/calls/${id}`, {
      method: 'DELETE',
    });
  }

  async processRefund(callId: string, amount: number, reason: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/calls/${callId}/refund`, {
      method: 'POST',
      body: JSON.stringify({ amount, reason }),
    });
  }

  async addCallNote(callId: string, note: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/calls/${callId}/notes`, {
      method: 'POST',
      body: JSON.stringify({ note }),
    });
  }

  // 文档翻译API
  async getDocument(id: string): Promise<ApiResponse<DocumentTranslation>> {
    return this.request<DocumentTranslation>(`/documents/${id}`);
  }

  async updateDocument(id: string, data: Partial<DocumentTranslation>): Promise<ApiResponse<DocumentTranslation>> {
    return this.request<DocumentTranslation>(`/documents/${id}`, {
      method: 'PUT',
      body: JSON.stringify(data),
    });
  }

  async deleteDocument(id: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/documents/${id}`, {
      method: 'DELETE',
    });
  }

  async reassignTranslator(documentId: string, translatorId: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/documents/${documentId}/reassign`, {
      method: 'POST',
      body: JSON.stringify({ translatorId }),
    });
  }

  async retranslateDocument(documentId: string, quality: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/documents/${documentId}/retranslate`, {
      method: 'POST',
      body: JSON.stringify({ quality }),
    });
  }

  async addDocumentNote(documentId: string, note: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/documents/${documentId}/notes`, {
      method: 'POST',
      body: JSON.stringify({ note }),
    });
  }

  // 预约管理API
  async getAppointment(id: string): Promise<ApiResponse<Appointment>> {
    return this.request<Appointment>(`/appointments/${id}`);
  }

  async updateAppointment(id: string, data: Partial<Appointment>): Promise<ApiResponse<Appointment>> {
    return this.request<Appointment>(`/appointments/${id}`, {
      method: 'PUT',
      body: JSON.stringify(data),
    });
  }

  async deleteAppointment(id: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/appointments/${id}`, {
      method: 'DELETE',
    });
  }

  async rescheduleAppointment(
    appointmentId: string, 
    newStartTime: string, 
    newEndTime: string
  ): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/appointments/${appointmentId}/reschedule`, {
      method: 'POST',
      body: JSON.stringify({ newStartTime, newEndTime }),
    });
  }

  async reassignAppointmentTranslator(
    appointmentId: string, 
    translatorId: string
  ): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/appointments/${appointmentId}/reassign`, {
      method: 'POST',
      body: JSON.stringify({ translatorId }),
    });
  }

  async addAppointmentNote(appointmentId: string, note: string): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/appointments/${appointmentId}/notes`, {
      method: 'POST',
      body: JSON.stringify({ note }),
    });
  }

  // 退款处理API
  async refundPayment(paymentId: string, amount: number): Promise<ApiResponse<boolean>> {
    return this.request<boolean>(`/payments/${paymentId}/refund`, {
      method: 'POST',
      body: JSON.stringify({ amount }),
    });
  }

  // 统计数据API
  async getStatistics(): Promise<ApiResponse<any>> {
    return this.request<any>('/statistics');
  }

  // 用户管理API
  async getUsers(page: number = 1, pageSize: number = 10): Promise<ApiResponse<any>> {
    return this.request<any>(`/users?page=${page}&pageSize=${pageSize}`);
  }

  async updateUser(userId: string, data: any): Promise<ApiResponse<any>> {
    return this.request<any>(`/users/${userId}`, {
      method: 'PUT',
      body: JSON.stringify(data),
    });
  }

  // 译员管理API
  async getTranslators(page: number = 1, pageSize: number = 10): Promise<ApiResponse<any>> {
    return this.request<any>(`/translators?page=${page}&pageSize=${pageSize}`);
  }

  async updateTranslator(translatorId: string, data: any): Promise<ApiResponse<any>> {
    return this.request<any>(`/translators/${translatorId}`, {
      method: 'PUT',
      body: JSON.stringify(data),
    });
  }

  // 系统配置API
  async getSystemConfig(): Promise<ApiResponse<any>> {
    return this.request<any>('/config');
  }

  async updateSystemConfig(config: any): Promise<ApiResponse<any>> {
    return this.request<any>('/config', {
      method: 'PUT',
      body: JSON.stringify(config),
    });
  }
}

// 导出API实例
export const api = new ApiManager();
export default api; 